@@ -32,6 +32,13 @@ private Q_SLOTS:
     void benchCheckValidity();
     void benchRangeForLine();
     void testMultiblockRangeWithLineUnwrapping();
+    void testRangeSurvivesDocument();
+    void testRangeWithDynAttrNoCrash();
+    void testNoCrashIfFeedbackWasClearedBeforeDtor();
+    void testNoCrashIfDynAttrWasClearedBeforeDtor();
+    void testNoCrashWithMultiblockRange();
+    void testNoFlippedRange();
+    void testBlockSplitAndMerge();
 };
 
 #endif // KATE_MOVINGRANGE_TEST_H
