@@ -21,18 +21,14 @@ class DocumentPrivate;
 
 class KateModeMenu : public KActionMenu
 {
-    Q_OBJECT
-
 public:
     KateModeMenu(const QString &text, QObject *parent)
         : KActionMenu(text, parent)
     {
         init();
-        setDelayed(false);
+        setPopupMode(QToolButton::InstantPopup);
     }
 
-    ~KateModeMenu();
-
     void updateMenu(KTextEditor::Document *doc);
 
 private:
@@ -44,10 +40,10 @@ private:
     QList<QMenu *> subMenus;
     QActionGroup *m_actionGroup;
 
-public Q_SLOTS:
+public:
     void slotAboutToShow();
 
-private Q_SLOTS:
+private:
     void setType(QAction *);
 };
 
