@@ -2,7 +2,7 @@ var katescript = {
     "name": "C Style",
     "author": "Dominik Haumann <dhdev@gmx.de>, Milian Wolff <mail@milianw.de>",
     "license": "LGPL",
-    "revision": 6,
+    "revision": 7,
     "kate-version": "5.1"
 }; // kate-script-header, must be at the start of the file without comments, pure json
 
@@ -623,20 +623,22 @@ function tryStatement(line)
                 }
             }
         } else if (result[2] == ',' && !currentString.match(/\(/)) {
-            // assume a function call: check for '(' brace
-            // - if not found, use previous indentation
+            // assume a function call: check for '(' and '{'
+            // - if '{' found and its nearer OR if '(' not found, use previous indentation
             // - if found, compare the indentation depth of current line and open brace line
             //   - if current indentation depth is smaller, use that
             //   - otherwise, use the '(' indentation + following white spaces
             var currentIndentation = document.firstVirtualColumn(currentLine);
-            var braceCursor = document.anchor(currentLine, result[1].length, '(');
+            var braceCursor = document.anchor(currentLine, result[1].length, '{');
+            var parenCursor = document.anchor(currentLine, result[1].length, '(');
 
-            if (!braceCursor.isValid() || currentIndentation < braceCursor.column)
+            if ((braceCursor.isValid() && braceCursor > parenCursor) || currentIndentation < parenCursor.column) {
                 indentation = currentIndentation;
-            else {
-                indentation = braceCursor.column + 1;
-                while (document.isSpace(braceCursor.line, indentation))
+            } else {
+                indentation = parenCursor.column + 1;
+                while (document.isSpace(parenCursor.line, indentation)) {
                     ++indentation;
+                }
             }
         } else if (gMode == "Dart" && result[2] == ',' && currentString.contains("(") && currentString.contains(")")) {
             // Dart has a lot of stuff and function calls inside ctors
@@ -735,10 +737,10 @@ function tryMatchedAnchor(line, alignOnly)
                 // otherwise don't add a new line, just align on closing anchor
                 indentation = document.toVirtualColumn(closingAnchor) + 1;
             }
-            dbg("tryMatchedAnchor: success in line " + closingAnchor.line);
+            dbg("tryMatchedAnchor(1): success in line " + closingAnchor.line);
             return indentation;
         } else if ( lastChar == ',') {
-            dbg("tryMatchedAnchor: success in line " + closingAnchor.line);
+            dbg("tryMatchedAnchor(2): success in line " + closingAnchor.line);
             return document.toVirtualColumn(closingAnchor) + 1;
         }
     }
@@ -746,30 +748,36 @@ function tryMatchedAnchor(line, alignOnly)
     // otherwise we i.e. pressed enter between (), [] or when we enter before curly brace
     // increase indentation and place closing anchor on the next line
     indentation = document.firstVirtualColumn(closingAnchor.line);
-    document.insertText(line, document.firstColumn(line), "\n");
-    view.setCursorPosition(line, indentation);
+    var firstColumnInPrevLine = document.firstVirtualColumn(line - 1);
+    if (line - 1 == closingAnchor.line || firstColumnInPrevLine >= 0) {
+        // the opening / close bracket were on same line or there was some text before the curly
+        document.insertText(line, document.firstColumn(line), "\n");
+        view.setCursorPosition(line, indentation);
+    } else {
+        // The curly was the only thing on the line, just retain the indent
+        dbg("tryMatchedAnchor(3): success retain indent");
+        return indentation;
+    }
     // indent closing brace
     document.indent(new Range(line + 1, 0, line + 1, 1), indentation / gIndentWidth);
-    dbg("tryMatchedAnchor: success in line " + closingAnchor.line);
+    dbg("tryMatchedAnchor(4): success in line " + closingAnchor.line);
     return indentation + gIndentWidth;
 }
 
-function escapeForRegex(string) {
-    if (string !== null) {
-        return string.replace(/[-\/\\^$*+?.()|[\]{}]/g, '\\$&');
-    }
-    return string;
-}
-
 /**
  * Don't indent on multiline string literals of form R"[optional delimiter text]()[optional delimiter text]"
  */
-function tryMultiLineStringLiteral(line) {
+function tryMultiLineStringLiteral(line, alignOnly) {
+    // The algorithm in this function is only valid for C++, don't waste time for other languages
+    if (!gMode.contains("C++")) {
+        return -1;
+    }
     var currentLine = line;
     var currentString;
     var delim = "";
     var found = false;
 
+    var limit = 0; // ensure we don't search the whole document all the time
     // go line up as long as the previous line ends with an escape character '\'
     // go line up until we find something of form R"[delim](
     while (currentLine >= 0) {
@@ -777,35 +785,46 @@ function tryMultiLineStringLiteral(line) {
         var startMatch = currentString.match(multiLineStringLiteralStartRegex);
         if (startMatch !== null) {
             found = true;
-            delim = startMatch[1];
+            delim = startMatch[1] || "";
+            currentLine--;
             break;
         }
         --currentLine;
+        if (limit >= 25) {
+            break;
+        }
+        limit++;
     }
 
     if (!found) {
         return -1;
     }
 
+    const delimStartLine = currentLine;
+
     // iterate through all lines and toggle bool insideString for every quote
-    var insideString = true;
-    var endReached = false;
-    var indentation = null;
-    const multiLineStringLiteralEndRegex = new RegExp('\\)' + escapeForRegex(delim) + '"');
+    const multiLineStringLiteralEnd = `)${delim}"`;
     while (currentLine < line) {
         currentString = document.line(currentLine);
-        dbg(currentString);
-        var endMatch = currentString.match(multiLineStringLiteralEndRegex);
-        if (endMatch !== null) {
+        var endMatch = currentString.indexOf(multiLineStringLiteralEnd);
+        if (endMatch !== -1) {
             dbg("End reached: " + currentString);
-            endReached = true;
-            break;
+            return -1;
         }
         ++currentLine;
     }
-    indentation = document.firstVirtualColumn(line);
-    dbg(endReached ? -1 : indentation);
-    return endReached ? -1 : indentation;
+
+    // when aligning only, do nothing
+    if (alignOnly) {
+        const indent = document.firstVirtualColumn(line);
+        return indent === -1 ? 0 : indent;
+    }
+
+    const prevNonEmpty = document.prevNonEmptyLine(line - 1);
+    if (delimStartLine === prevNonEmpty) {
+        return 0;
+    }
+    return document.firstVirtualColumn(prevNonEmpty);
 }
 
 /**
@@ -826,7 +845,7 @@ function indentLine(line, alignOnly)
     if (filler == -1 && !alignOnly)
         filler = tryCppComment(line);
     if (filler == -1)
-        filler = tryMultiLineStringLiteral(line);
+        filler = tryMultiLineStringLiteral(line, alignOnly);
     if (filler == -1)
         filler = tryString(line);
     if (filler == -1)
