@@ -9,6 +9,7 @@
 #include <QModelIndex>
 #include <QRegularExpression>
 
+#include <kateconfig.h>
 #include <ktexteditor/document.h>
 #include <ktexteditor/view.h>
 
@@ -18,9 +19,7 @@ CodeCompletionModelControllerInterface::CodeCompletionModelControllerInterface()
 {
 }
 
-CodeCompletionModelControllerInterface::~CodeCompletionModelControllerInterface()
-{
-}
+CodeCompletionModelControllerInterface::~CodeCompletionModelControllerInterface() = default;
 
 bool CodeCompletionModelControllerInterface::shouldStartCompletion(View *view, const QString &insertedText, bool userInsertion, const Cursor &position)
 {
@@ -30,8 +29,9 @@ bool CodeCompletionModelControllerInterface::shouldStartCompletion(View *view, c
         return false;
     }
 
-    QChar lastChar = insertedText.at(insertedText.count() - 1);
-    if ((userInsertion && (lastChar.isLetter() || lastChar.isNumber() || lastChar == QLatin1Char('_'))) || lastChar == QLatin1Char('.') || insertedText.endsWith(QLatin1String("->"))) {
+    QChar lastChar = insertedText.at(insertedText.size() - 1);
+    if ((userInsertion && (lastChar.isLetter() || lastChar.isNumber() || lastChar == QLatin1Char('_'))) || lastChar == QLatin1Char('.')
+        || insertedText.endsWith(QLatin1String("->"))) {
         return true;
     }
     return false;
@@ -40,11 +40,14 @@ bool CodeCompletionModelControllerInterface::shouldStartCompletion(View *view, c
 Range CodeCompletionModelControllerInterface::completionRange(View *view, const Cursor &position)
 {
     Cursor end = position;
+    const int line = end.line();
 
-    QString text = view->document()->line(end.line());
+    const QString lineText = view->document()->line(line);
+    QStringView text = lineText;
 
-    static const QRegularExpression findWordStart(QStringLiteral("\\b[_\\w]+$"));
-    static const QRegularExpression findWordEnd(QStringLiteral("^[_\\w]*\\b"));
+    static constexpr auto options = QRegularExpression::UseUnicodePropertiesOption | QRegularExpression::DontCaptureOption;
+    static const QRegularExpression findWordStart(QStringLiteral("\\b[_\\w]+$"), options);
+    static const QRegularExpression findWordEnd(QStringLiteral("^[_\\w]*\\b"), options);
 
     Cursor start = end;
 
@@ -53,13 +56,19 @@ Range CodeCompletionModelControllerInterface::completionRange(View *view, const
         start.setColumn(pos);
     }
 
-    QRegularExpressionMatch match;
-    pos = text.mid(end.column()).indexOf(findWordEnd, 0, &match);
-    if (pos >= 0) {
-        end.setColumn(end.column() + match.capturedLength());
-    }
+    if (!KateViewConfig::global()->wordCompletionRemoveTail()) {
+        // We are not removing tail, range only contains the word left of the cursor
+        return Range(start, position);
+    } else {
+        // Removing tail, find the word end
+        QRegularExpressionMatch match;
+        pos = text.mid(end.column()).indexOf(findWordEnd, 0, &match);
+        if (pos >= 0) {
+            end.setColumn(end.column() + match.capturedLength());
+        }
 
-    return Range(start, end);
+        return Range(start, end);
+    }
 }
 
 Range CodeCompletionModelControllerInterface::updateCompletionRange(View *view, const Range &range)
@@ -86,7 +95,7 @@ bool CodeCompletionModelControllerInterface::shouldAbortCompletion(View *view, c
     }
     // Do not abort completions when the text has been empty already before and a newline has been entered
 
-    static const QRegularExpression allowedText(QStringLiteral("^\\w*$"));
+    static const QRegularExpression allowedText(QStringLiteral("^\\w*$"), QRegularExpression::UseUnicodePropertiesOption);
     return !allowedText.match(currentCompletion).hasMatch();
 }
 
