@@ -1,44 +1,26 @@
-/*  SPDX-License-Identifier: LGPL-2.0-or-later
+/*
+    SPDX-FileCopyrightText: 2003-2005 Anders Lund <anders@alweb.dk>
+    SPDX-FileCopyrightText: 2001-2010 Christoph Cullmann <cullmann@kde.org>
+    SPDX-FileCopyrightText: 2001 Charles Samuels <charles@kde.org>
 
-    Copyright (C) 2003-2005 Anders Lund <anders@alweb.dk>
-    Copyright (C) 2001-2010 Christoph Cullmann <cullmann@kde.org>
-    Copyright (C) 2001 Charles Samuels <charles@kde.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include <vimode/cmds.h>
 
 #include "globalstate.h"
 #include "katecmd.h"
-#include "katedocument.h"
-#include "kateglobal.h"
-#include "katepartdebug.h"
 #include "kateview.h"
 #include "kateviinputmode.h"
 #include "marks.h"
 #include <vimode/emulatedcommandbar/emulatedcommandbar.h>
 #include <vimode/inputmodemanager.h>
 #include <vimode/modes/normalvimode.h>
+#include <vimode/searcher.h>
 
 #include <KLocalizedString>
 
-#include <QDir>
 #include <QRegularExpression>
-#include <QUrl>
 
 using namespace KateVi;
 
@@ -57,22 +39,31 @@ bool Commands::exec(KTextEditor::View *view, const QString &_cmd, QString &msg,
     }
 
     // create a list of args
-    QStringList args(_cmd.split(QRegularExpression(QStringLiteral("\\s+")), QString::SkipEmptyParts));
+    QStringList args(_cmd.split(QRegularExpression(QStringLiteral("\\s+")), Qt::SkipEmptyParts));
     QString cmd(args.takeFirst());
 
     // ALL commands that takes no arguments.
     if (mappingCommands().contains(cmd)) {
         if (cmd.endsWith(QLatin1String("unmap"))) {
             if (args.count() == 1) {
-                m_viGlobal->mappings()->remove(modeForMapCommand(cmd), args.at(0));
+                m_viInputModeManager->globalState()->mappings()->remove(modeForMapCommand(cmd), args.at(0));
                 return true;
             } else {
                 msg = i18n("Missing argument. Usage: %1 <from>", cmd);
                 return false;
             }
+        } else if (cmd == QLatin1String("nohlsearch") || cmd == QLatin1String("noh")) {
+            m_viInputModeManager->searcher()->hideCurrentHighlight();
+            return true;
+        } else if (cmd == QLatin1String("set-hlsearch") || cmd == QLatin1String("set-hls")) {
+            m_viInputModeManager->searcher()->enableHighlightSearch(true);
+            return true;
+        } else if (cmd == QLatin1String("set-nohlsearch") || cmd == QLatin1String("set-nohls")) {
+            m_viInputModeManager->searcher()->enableHighlightSearch(false);
+            return true;
         }
         if (args.count() == 1) {
-            msg = m_viGlobal->mappings()->get(modeForMapCommand(cmd), args.at(0), true);
+            msg = m_viInputModeManager->globalState()->mappings()->get(modeForMapCommand(cmd), args.at(0), true);
             if (msg.isEmpty()) {
                 msg = i18n("No mapping found for \"%1\"", args.at(0));
                 return false;
@@ -81,7 +72,7 @@ bool Commands::exec(KTextEditor::View *view, const QString &_cmd, QString &msg,
             }
         } else if (args.count() == 2) {
             Mappings::MappingRecursion mappingRecursion = (isMapCommandRecursive(cmd)) ? Mappings::Recursive : Mappings::NonRecursive;
-            m_viGlobal->mappings()->add(modeForMapCommand(cmd), args.at(0), args.at(1), mappingRecursion);
+            m_viInputModeManager->globalState()->mappings()->add(modeForMapCommand(cmd), args.at(0), args.at(1), mappingRecursion);
         } else {
             msg = i18n("Missing argument(s). Usage: %1 <from> [<to>]", cmd);
             return false;
@@ -92,8 +83,8 @@ bool Commands::exec(KTextEditor::View *view, const QString &_cmd, QString &msg,
 
     NormalViMode *nm = m_viInputModeManager->getViNormalMode();
 
-    if (cmd == QLatin1String("d") || cmd == QLatin1String("delete") || cmd == QLatin1String("j") || cmd == QLatin1String("c") || cmd == QLatin1String("change") || cmd == QLatin1String("<") || cmd == QLatin1String(">") ||
-        cmd == QLatin1String("y") || cmd == QLatin1String("yank")) {
+    if (cmd == QLatin1String("d") || cmd == QLatin1String("delete") || cmd == QLatin1String("j") || cmd == QLatin1String("c") || cmd == QLatin1String("change")
+        || cmd == QLatin1String("<") || cmd == QLatin1String(">") || cmd == QLatin1String("y") || cmd == QLatin1String("yank")) {
         KTextEditor::Cursor start_cursor_position = v->cursorPosition();
 
         int count = 1;
@@ -110,7 +101,9 @@ bool Commands::exec(KTextEditor::View *view, const QString &_cmd, QString &msg,
             }
 
             QChar r = args.at(i).at(0);
-            if (args.at(i).size() == 1 && ((r >= QLatin1Char('a') && r <= QLatin1Char('z')) || r == QLatin1Char('_') || r == QLatin1Char('+') || r == QLatin1Char('*'))) {
+            if (args.at(i).size() == 1
+                && ((r >= QLatin1Char('a') && r <= QLatin1Char('z')) || r == QLatin1Char('_') || r == QLatin1Char('-') || r == QLatin1Char('+')
+                    || r == QLatin1Char('*'))) {
                 nm->setRegister(r);
             }
         }
@@ -180,9 +173,10 @@ bool Commands::supportsRange(const QString &range)
 {
     static QStringList l;
 
-    if (l.isEmpty())
-        l << QStringLiteral("d") << QStringLiteral("delete") << QStringLiteral("j") << QStringLiteral("c") << QStringLiteral("change") << QStringLiteral("<") << QStringLiteral(">") << QStringLiteral("y") << QStringLiteral("yank")
-          << QStringLiteral("ma") << QStringLiteral("mark") << QStringLiteral("k");
+    if (l.isEmpty()) {
+        l << QStringLiteral("d") << QStringLiteral("delete") << QStringLiteral("j") << QStringLiteral("c") << QStringLiteral("change") << QStringLiteral("<")
+          << QStringLiteral(">") << QStringLiteral("y") << QStringLiteral("yank") << QStringLiteral("ma") << QStringLiteral("mark") << QStringLiteral("k");
+    }
 
     return l.contains(range.split(QLatin1Char(' ')).at(0));
 }
@@ -194,7 +188,7 @@ KCompletion *Commands::completionObject(KTextEditor::View *view, const QString &
     KTextEditor::ViewPrivate *v = static_cast<KTextEditor::ViewPrivate *>(view);
 
     if (v && (cmd == QLatin1String("nn") || cmd == QLatin1String("nnoremap"))) {
-        QStringList l = m_viGlobal->mappings()->getAll(Mappings::NormalModeMapping);
+        QStringList l = m_viInputModeManager->globalState()->mappings()->getAll(Mappings::NormalModeMapping);
 
         KateCmdShellCompletion *co = new KateCmdShellCompletion();
         co->setItems(l);
@@ -208,55 +202,51 @@ const QStringList &Commands::mappingCommands()
 {
     static QStringList mappingsCommands;
     if (mappingsCommands.isEmpty()) {
-        mappingsCommands << QStringLiteral("nmap") << QStringLiteral("nm") << QStringLiteral("noremap") << QStringLiteral("nnoremap") << QStringLiteral("nn") << QStringLiteral("no") << QStringLiteral("vmap") << QStringLiteral("vm")
-                         << QStringLiteral("vnoremap") << QStringLiteral("vn") << QStringLiteral("imap") << QStringLiteral("im") << QStringLiteral("inoremap") << QStringLiteral("ino") << QStringLiteral("cmap") << QStringLiteral("cm")
-                         << QStringLiteral("cnoremap") << QStringLiteral("cno");
+        mappingsCommands << QStringLiteral("nmap") << QStringLiteral("nm") << QStringLiteral("noremap") << QStringLiteral("nnoremap") << QStringLiteral("nn")
+                         << QStringLiteral("no") << QStringLiteral("vmap") << QStringLiteral("vm") << QStringLiteral("vnoremap") << QStringLiteral("vn")
+                         << QStringLiteral("imap") << QStringLiteral("im") << QStringLiteral("inoremap") << QStringLiteral("ino") << QStringLiteral("cmap")
+                         << QStringLiteral("cm") << QStringLiteral("cnoremap") << QStringLiteral("cno");
 
         mappingsCommands << QStringLiteral("nunmap") << QStringLiteral("vunmap") << QStringLiteral("iunmap") << QStringLiteral("cunmap");
+
+        mappingsCommands << QStringLiteral("nohlsearch") << QStringLiteral("noh") << QStringLiteral("set-hlsearch") << QStringLiteral("set-hls")
+                         << QStringLiteral("set-nohlsearch") << QStringLiteral("set-nohls");
     }
     return mappingsCommands;
 }
 
 Mappings::MappingMode Commands::modeForMapCommand(const QString &mapCommand)
 {
-    static QMap<QString, Mappings::MappingMode> modeForMapCommand;
-    if (modeForMapCommand.isEmpty()) {
-        // Normal is the default.
-        modeForMapCommand.insert(QStringLiteral("vmap"), Mappings::VisualModeMapping);
-        modeForMapCommand.insert(QStringLiteral("vm"), Mappings::VisualModeMapping);
-        modeForMapCommand.insert(QStringLiteral("vnoremap"), Mappings::VisualModeMapping);
-        modeForMapCommand.insert(QStringLiteral("vn"), Mappings::VisualModeMapping);
-        modeForMapCommand.insert(QStringLiteral("imap"), Mappings::InsertModeMapping);
-        modeForMapCommand.insert(QStringLiteral("im"), Mappings::InsertModeMapping);
-        modeForMapCommand.insert(QStringLiteral("inoremap"), Mappings::InsertModeMapping);
-        modeForMapCommand.insert(QStringLiteral("ino"), Mappings::InsertModeMapping);
-        modeForMapCommand.insert(QStringLiteral("cmap"), Mappings::CommandModeMapping);
-        modeForMapCommand.insert(QStringLiteral("cm"), Mappings::CommandModeMapping);
-        modeForMapCommand.insert(QStringLiteral("cnoremap"), Mappings::CommandModeMapping);
-        modeForMapCommand.insert(QStringLiteral("cno"), Mappings::CommandModeMapping);
-
-        modeForMapCommand.insert(QStringLiteral("nunmap"), Mappings::NormalModeMapping);
-        modeForMapCommand.insert(QStringLiteral("vunmap"), Mappings::VisualModeMapping);
-        modeForMapCommand.insert(QStringLiteral("iunmap"), Mappings::InsertModeMapping);
-        modeForMapCommand.insert(QStringLiteral("cunmap"), Mappings::CommandModeMapping);
+    if (mapCommand.startsWith(u'v')) {
+        if (mapCommand == u"vmap" || mapCommand == u"vm" || mapCommand == u"vn" || mapCommand == u"vnoremap" || mapCommand == u"vunmap") {
+            return Mappings::VisualModeMapping;
+        }
     }
-    return modeForMapCommand.value(mapCommand);
+
+    if (mapCommand.startsWith(u'i')) {
+        if (mapCommand == u"imap" || mapCommand == u"im" || mapCommand == u"ino" || mapCommand == u"inoremap" || mapCommand == u"iunmap") {
+            return Mappings::InsertModeMapping;
+        }
+    }
+
+    if (mapCommand.startsWith(u'c')) {
+        if (mapCommand == u"cmap" || mapCommand == u"cm" || mapCommand == u"cno" || mapCommand == u"cnoremap" || mapCommand == u"cunmap") {
+            return Mappings::CommandModeMapping;
+        }
+    }
+
+    // if (mapCommand == u"nunmap") {
+    //     return Mappings::NormalModeMapping;
+    // }
+    return Mappings::NormalModeMapping;
 }
 
 bool Commands::isMapCommandRecursive(const QString &mapCommand)
 {
-    static QMap<QString, bool> isMapCommandRecursive;
-    if (isMapCommandRecursive.isEmpty()) {
-        isMapCommandRecursive.insert(QStringLiteral("nmap"), true);
-        isMapCommandRecursive.insert(QStringLiteral("nm"), true);
-        isMapCommandRecursive.insert(QStringLiteral("vmap"), true);
-        isMapCommandRecursive.insert(QStringLiteral("vm"), true);
-        isMapCommandRecursive.insert(QStringLiteral("imap"), true);
-        isMapCommandRecursive.insert(QStringLiteral("im"), true);
-        isMapCommandRecursive.insert(QStringLiteral("cmap"), true);
-        isMapCommandRecursive.insert(QStringLiteral("cm"), true);
-    }
-    return isMapCommandRecursive.value(mapCommand);
+    return mapCommand == u"nmap" || mapCommand == u"nm" //
+        || mapCommand == u"vmap" || mapCommand == u"vm" //
+        || mapCommand == u"imap" || mapCommand == u"im" //
+        || mapCommand == u"cmap" || mapCommand == u"cm";
 }
 
 // END ViCommands
@@ -264,7 +254,7 @@ bool Commands::isMapCommandRecursive(const QString &mapCommand)
 // BEGIN SedReplace
 SedReplace *SedReplace::m_instance = nullptr;
 
-bool SedReplace::interactiveSedReplace(KTextEditor::ViewPrivate *, QSharedPointer<InteractiveSedReplacer> interactiveSedReplace)
+bool SedReplace::interactiveSedReplace(KTextEditor::ViewPrivate *, std::shared_ptr<InteractiveSedReplacer> interactiveSedReplace)
 {
     EmulatedCommandBar *emulatedCommandBar = m_viInputModeManager->inputAdapter()->viModeEmulatedCommandBar();
     emulatedCommandBar->startInteractiveSearchAndReplace(interactiveSedReplace);
