@@ -18,11 +18,14 @@
 
 #include "completionrecorder.h"
 #include "completionreplayer.h"
+#include "definitions.h"
 #include "globalstate.h"
 #include "jumps.h"
 #include "kateconfig.h"
 #include "katedocument.h"
 #include "kateglobal.h"
+#include "katerenderer.h"
+#include "kateview.h"
 #include "kateviewinternal.h"
 #include "kateviinputmode.h"
 #include "lastchangerecorder.h"
@@ -58,7 +61,7 @@ InputModeManager::InputModeManager(KateViInputMode *inputAdapter, KTextEditor::V
 
     m_insideHandlingKeyPressCount = 0;
 
-    m_keyMapperStack.push(QSharedPointer<KeyMapper>(new KeyMapper(this, m_view->doc(), m_view)));
+    m_keyMapperStack.push(std::make_shared<KeyMapper>(this, m_view->doc()));
 
     m_temporaryNormalMode = false;
 
@@ -173,7 +176,7 @@ void InputModeManager::feedKeyPresses(const QString &keyPresses) const
 
                 int c = decoded.indexOf(QLatin1String("c-"));
                 if (c != -1) {
-                    mods |= Qt::ControlModifier;
+                    mods |= CONTROL_MODIFIER;
                     decoded.remove(c, 2);
                 }
 
@@ -185,7 +188,7 @@ void InputModeManager::feedKeyPresses(const QString &keyPresses) const
 
                 int m = decoded.indexOf(QLatin1String("m-"));
                 if (m != -1) {
-                    mods |= Qt::MetaModifier;
+                    mods |= META_MODIFIER;
                     decoded.remove(m, 2);
                 }
 
@@ -334,7 +337,7 @@ void InputModeManager::viEnterNormalMode()
     if (moveCursorLeft) {
         m_viewInternal->cursorPrevChar();
     }
-    m_inputAdapter->setCaretStyle(KateRenderer::Block);
+    m_inputAdapter->setCaretStyle(KTextEditor::caretStyles::Block);
     m_viewInternal->update();
 }
 
@@ -347,7 +350,7 @@ void InputModeManager::viEnterInsertMode()
         // after returning from temporary normal mode will be treated as commands!
         m_lastChangeRecorder->record(QKeyEvent(QEvent::KeyPress, Qt::Key_I, Qt::NoModifier, QStringLiteral("i")));
     }
-    m_inputAdapter->setCaretStyle(KateRenderer::Line);
+    m_inputAdapter->setCaretStyle(KTextEditor::caretStyles::Line);
     setTemporaryNormalMode(false);
     m_viewInternal->update();
 }
@@ -358,7 +361,7 @@ void InputModeManager::viEnterVisualMode(ViMode mode)
 
     // If the selection is inclusive, the caret should be a block.
     // If the selection is exclusive, the caret should be a line.
-    m_inputAdapter->setCaretStyle(KateRenderer::Block);
+    m_inputAdapter->setCaretStyle(KTextEditor::caretStyles::Block);
     m_viewInternal->update();
     getViVisualMode()->setVisualModeType(mode);
     getViVisualMode()->init();
@@ -368,7 +371,7 @@ void InputModeManager::viEnterReplaceMode()
 {
     changeViMode(ViMode::ReplaceMode);
     m_marks->setStartEditYanked(KTextEditor::Cursor(m_view->cursorPosition()));
-    m_inputAdapter->setCaretStyle(KateRenderer::Underline);
+    m_inputAdapter->setCaretStyle(KTextEditor::caretStyles::Underline);
     m_viewInternal->update();
 }
 
@@ -435,10 +438,10 @@ void InputModeManager::reset()
 
 KeyMapper *InputModeManager::keyMapper()
 {
-    return m_keyMapperStack.top().data();
+    return m_keyMapperStack.top().get();
 }
 
-void InputModeManager::updateCursor(const KTextEditor::Cursor &c)
+void InputModeManager::updateCursor(const KTextEditor::Cursor c)
 {
     m_inputAdapter->updateCursor(c);
 }
@@ -453,7 +456,7 @@ KTextEditor::ViewPrivate *InputModeManager::view() const
     return m_view;
 }
 
-void InputModeManager::pushKeyMapper(QSharedPointer<KeyMapper> mapper)
+void InputModeManager::pushKeyMapper(std::shared_ptr<KeyMapper> mapper)
 {
     m_keyMapperStack.push(mapper);
 }
